pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Tom Lane <tgl@sss.pgh.pa.us>
To: Rhett Garber <rhettg@gmail.com>
Cc: Havasvölgyi Ottó <h.otto@freemail.hu>
Cc: pgsql-performance@postgresql.org
Subject: Re: Why hash join instead of nested loop?
Date: Sat, 06 Aug 2005 01:03:51 -0400
Message-ID: <15425.1123304631@sss.pgh.pa.us> (raw)
In-Reply-To: <41b0fe8905080516164464e04f@mail.gmail.com>
References: <41b0fe890508051135712a086b@mail.gmail.com>
	<001801c59a0a$f4be7480$9a00a8c0@OTTO>
	<41b0fe8905080516164464e04f@mail.gmail.com>

Rhett Garber <rhettg@gmail.com> writes:
> Hash Join  (cost=5.96..7.04 rows=1 width=14) (actual
> time=10.591..10.609 rows=1 loops=1)
>    Hash Cond: ("outer".id = "inner".obj2)
>    ->  Seq Scan on rtmessagestate  (cost=0.00..1.05 rows=5 width=14)
> (actual time=0.011..0.022 rows=5 loops=1)
>    ->  Hash  (cost=5.96..5.96 rows=1 width=4) (actual
> time=0.109..0.109 rows=0 loops=1)
>          ->  Index Scan using connection_regid_obj1_index on
> connection  (cost=0.00..5.96 rows=1 width=4) (actual time=0.070..0.076
> rows=1 loops=1)
>                Index Cond: ((connection_registry_id = 40105) AND (obj1
> = 73582)) Total runtime: 11.536 ms
> (7 rows)

[ scratches head... ]  If the hash table build takes only 0.109 msec
and loads only one row into the hash table, and the scan of
rtmessagestate takes only 0.022 msec and produces only 5 rows, it is
real hard to see how the join takes 10.609 msec overall.  Unless the id
and obj2 columns are of a datatype with an incredibly slow equality
function.  What is the datatype involved here, anyway?  And what PG
version are we speaking of?

			regards, tom lane



view thread (18+ messages)  latest in thread

Message-ID: <15425.1123304631@sss.pgh.pa.us>
Permalink:  ../15425.1123304631@sss.pgh.pa.us/
Also on:    postgresql.org/message-id/15425.1123304631@sss.pgh.pa.us

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: tgl@sss.pgh.pa.us, rhettg@gmail.com, h.otto@freemail.hu
  Subject: Re: Why hash join instead of nested loop?
  In-Reply-To: <15425.1123304631@sss.pgh.pa.us>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox